#!/usr/bin/env python

"""
Script to be used with logrotate, takes the rotated log and move it to
the correct path according to database setting.
"""

import psycopg2
import shutil
import sys
from datetime import datetime, date, timedelta
import subprocess
import os

def get_local_storage_path_setting(conn):
    """ Get the current setting for where to store the logfiles

    Returns: path to logfiles
    """
    cur = conn.cursor()
    cur.execute("SELECT storage_path from settings;")
    storage_path = cur.fetchone()[0]
    cur.close()

    return storage_path

def rotate_log(destination):
    """ Crawls 'path' for logfiles (files that doesn't have .bz2) and compress
    them, then move to where you have your local_storage. 'destination' points to the
    root path where compressed logfiles are stored. If 'destination' holds a
    "false" value (False/None/""/...), the logfiles are unlinked instead of compressed.
    In other words, an undefined 'destination' disables archiving.
    """
    path = '/var/log/op5/logger'

    rotate_date = datetime.now() - timedelta(hours=1)

    for f in os.listdir(path):
        if f.endswith('bz2'):
            continue

        year, month, day, hour = f.split('_')
        file_mtime = datetime.strptime('%s-%s-%s %s:00:00' % (year, month, day, hour), '%Y-%m-%d %H:00:00')
        if file_mtime < rotate_date:
            if not destination:
                os.unlink(os.path.join(path, f))
                continue

            ret = subprocess.call('bzip2 %s' % (os.path.join(path, f)), shell=True)
            if ret == 0:
                local_archive = "%s/%s_%s/%s" % (destination, year, month, day)
                if not os.path.exists(local_archive):
                    os.makedirs(local_archive)
                shutil.move(os.path.join(path, f + '.bz2'), "%s/%s.bz2" % (local_archive, hour))

if __name__ == '__main__':
    try:
        conn = psycopg2.connect("dbname=op5lsu user=op5lsu")
    except:
        print "Unable to connect to database"
        sys.exit(1)

    rotate_log(get_local_storage_path_setting(conn))

    conn.close()
